@@ -9,7 +9,7 @@
 #'  - `bdate` within `bdate_range`
 #'
 #'  If the input object contains deposition dates (`ddate`, mostly in simulated profiles),
-#' but no `bdates`, they are automatically computed by [deriveDatetag];
+#' but no `bdates`, they are computed via [deriveBDate];
 #' otherwise the date window is applied to the `datetag` (mostly for manual profiles).
 #'
 #' If you apply thresholds to your search, only layers are returned that satisfy *at least one* of the provided thresholds.
@@ -17,13 +17,18 @@
 #' @describeIn findPWL Find layers of interest (e.g., PWLs) in `snowprofile` or `snowprofileLayers`
 #' @param x [snowprofile] or [snowprofileLayers] object
 #' @param pwl_gtype a vector of grain types of interest
-#' @param pwl_date a date of interest given as character ('YYYY-MM-DD') or as POSIXct; set to `NA` to ignore dates. If given as POSIXct, time comparison between layer dates and pwl_date
+#' @param pwl_date a date of interest given as character ('YYYY-MM-DD') or as POSIXct; set to `NA` to ignore dates.
+#' If given as POSIXct, time comparison between layer dates and pwl_date
 #' will consider the times of day (i.e., hours, etc). Otherwise only consider year/month/days.
-#' @param date_range a numeric array of length 2 that defines a date search window around `pwl_date`. This date range is applied to `ddate`s (deposition dates),
+#' @param date_variable Which layer dates do you want to consider? deposition and burial dates (`ddate`), or pre-computed
+#' datetags (`datetag`, see [assignDatetags] for more information)?
+#' @param date_range a numeric array of length 2 that defines a date search window around `pwl_date`. This date range is applied
+#' to `ddate`s (deposition dates),
 #' or if these are not available to `datetag`s.
 #' @param date_range_earlier a [difftime] object of `date_range[1]` (must be negative).
 #' @param date_range_later a [difftime] object of `date_range[2]` (must be positive).
-#' @param bdate_range a numeric array of length 2 that defines a date search window around `pwl_date`. This date range is applied to `bdate`s (burial dates)
+#' @param bdate_range a numeric array of length 2 that defines a date search window around `pwl_date`.
+#' This date range is applied to `bdate`s (burial dates)
 #' @param bdate_range_earlier a [difftime] object of `bdate_range[1]` (must be negative).
 #' @param bdate_range_later a [difftime] object of `bdate_range[2]` (must be positive).
 #' @param threshold_gtype specific grain types that are only deemed a PWL if they pass one or multiple thresholds (see next parameters)
@@ -69,7 +74,8 @@
 #' sapply(pwl_dates, function(dt) length(findPWL(tl, pwl_date = dt)) > 0)
 #'
 #' ## pwl_date example with proper profile:
-#' sp <- deriveDatetag(SPpairs$A_manual)
+#' potentialDatetags <- sort(unique(as.Date(SPpairs$A_modeled$layers$ddate)))
+#' sp <- suppressWarnings(assignDatetags(SPpairs$A_modeled, potentialDatetags))
 #' sp$layers
 #' pwl_dates <- paste0("2019-02-", seq(18, 26))
 #' names(pwl_dates) <- pwl_dates
@@ -96,6 +102,7 @@
 findPWL <- function(x,
                     pwl_gtype = c("SH", "DH"),
                     pwl_date = NA,
+                    date_variable = c("ddate", "datetag")[1],
                     date_range = c(-5, 0),
                     date_range_earlier = as.difftime(date_range[1], units = "days"),
                     date_range_later = as.difftime(date_range[2], units = "days"),
@@ -213,8 +220,11 @@ findPWL <- function(x,
       warning("bdate_range_earlier must be < 0! Multiplying by '-1'..")
       bdate_range_earlier <- -bdate_range_earlier
     }
-    if ("ddate" %in% names(layers)) {  # ddate available --> derive bdate
-      if (!"bdate" %in% names(layers)) layers <- deriveDatetag.snowprofileLayers(layers, checkMonotonicity = FALSE)
+    if ("ddate" %in% date_variable) {  # ddate available --> derive bdate
+      if (!'ddate' %in% names(layers)) stop("No ddate information available in snow layers!")
+      if (!"bdate" %in% names(layers)) {
+        layers <- deriveBDate.snowprofileLayers(layers, adjust_bdates = TRUE, checkMonotonicity = FALSE)
+      }
       if (!inherits(pwl_date, "POSIXct")) {   # convert to Date if pwl_date not given in POSIXct format
         layers$bdate <- as.Date(as.character(layers$bdate))  # double conversion ensures that timezone won't change from POSIXct to Date format!
         layers$ddate <- as.Date(as.character(layers$ddate))
@@ -227,7 +237,7 @@ findPWL <- function(x,
                      ((layers$bdate - pwl_date) >= as.difftime(bdate_range_earlier, units = "days") &
                         (layers$bdate - pwl_date) <= as.difftime(bdate_range_later, units = "days"))))
       return(idx)
-    } else if ("datetag" %in% names(layers)) {
+    } else if ("datetag" %in% date_variable) {
       layers$datetag <- as.Date(as.character(layers$datetag))
       pwl_date <- as.Date(as.character(pwl_date))
       idx <- which(PwlRows &
