@@ -16,6 +16,7 @@
 #' @param failureLayers.col color of arrow, can also be a vector of same length as `failureLayers` to color different arrows differently
 #' @param nYTicks number of tick marks at yaxis
 #' @param ymax the maximum ylim value
+#' @param ytick.las orientation of y-axis labels
 #' @param alignWithBottomUpPlot useful when aligning the yaxis grids of bottom up profileSet plots and top down hardness plots.
 #' @param highlightUnobservedBasalLayers draw sine wave at lowest observed layer to highlight unobserved layers below
 #' @param label.datetags label the datetags of the snowprofile layers? (Won't produce a pretty plot, but give you some more information for analysis)
@@ -56,6 +57,7 @@ plot.snowprofile <- function(x,
                              failureLayers.col = "red",
                              nYTicks = 4,
                              ymax = max(c(x$maxObservedDepth, x$hs), na.rm = TRUE),
+                             ytick.las = 1,
                              alignWithBottomUpPlot = FALSE,
                              highlightUnobservedBasalLayers = TRUE,
                              label.datetags = FALSE,
@@ -127,11 +129,11 @@ plot.snowprofile <- function(x,
   if (TempProfile) {
     ## check where to find temperature data
     if ("temperature" %in% names(Layers)) {
-      temps <- Layers$temperature
-      tempsHeight <- Layers$height
+      temps <- Layers$temperature[!is.na(Layers$temperature)]
+      tempsHeight <- Layers$height[!is.na(Layers$temperature)]
     } else if ("temperatureProfile" %in% names(Profile)) {
-      temps <- Profile$temperatureProfile$temperature
-      tempsHeight <- Profile$temperatureProfile$height
+      temps <- Profile$temperatureProfile$temperature[!is.na(Profile$temperatureProfile$temperature)]
+      tempsHeight <- Profile$temperatureProfile$height[!is.na(Profile$temperatureProfile$temperature)]
     } else {
       temps <- c()
     }
@@ -183,10 +185,10 @@ plot.snowprofile <- function(x,
         HeightGrid <- ymax - (DepthGrid + ymax - max(Layers$height))
 
       }
-      axis(2, at = HeightGrid, labels = DepthGrid)
+      axis(2, at = HeightGrid, labels = DepthGrid, las = ytick.las)
     } else {
       HeightGrid <- pretty(c(0, ymax), n = nYTicks)
-      axis(2, at = HeightGrid)
+      axis(2, at = HeightGrid, las = ytick.las)
     }
   }
 
@@ -201,7 +203,11 @@ plot.snowprofile <- function(x,
 
   ## label datetags if present
   if (label.datetags) {
-    if (!"datetag" %in% names(Layers)) suppressWarnings( Layers <- deriveDatetag(Layers) )
+    if (!"datetag" %in% names(Layers)) {
+      suppressWarnings(
+        Layers <- guessDatetagsSimple.snowprofileLayers(Layers, adjust_bdates = TRUE)
+      )
+    }
 
     labelsText = as.Date(Layers$datetag)
     ispaced <- which(!duplicated(labelsText))
