@@ -7,12 +7,14 @@
 #' To change the font size of labels etc, use `par()` with the parameters `cex.lab`, `cex.axis`, etc.
 #'
 #' @param x An object of class [snowprofileSet]
-#' @param SortMethod How to arrange profiles along the x-axis. Options include timeseries (default = 'time'), in existing order of Profiles list ('unsorted'), sorted by HS ('hs'), or elevation ('elev')
-#' @param ColParam What parameter to show with colour. So far the following types are available: "gtype", "hardness", "density", "temp", "gsize", "ssi", "p_unstable", "crit_cut_length", "rta", "percentage".
+#' @param SortMethod How to arrange profiles along the x-axis. Options include timeseries (default = 'time', or 'time_daily'), in existing order of Profiles list ('unsorted'),
+#' sorted by HS ('hs'), or elevation ('elev')
+#' @param ColParam What parameter to show with colour. So far the following types are available: "gtype", "hardness", "density", "temp", "gsize", "ssi", "p_unstable",
+#' "crit_cut_length", "rta", "percentage", "lwc".
 #' @param TopDown Option to plot by depth instead of height with zero depth on top of plot (default = FALSE)
 #' @param DateStart Start date for timeseries plots (`SortMethod = 'time'`). If not provided, the function takes the date range from Profiles (default = NA).
 #' @param DateEnd End date for timeseries plots (`SortMethod = 'time'`). If not provided, the function takes the date range from Profiles (default = NA).
-#' @param Timeseries_labels Label Saturdays "weekly", "monthly", or `NA`
+#' @param Timeseries_labels Label Saturdays "weekly", "monthly", "daily", "daily HH:MM", or `NA`
 #' @param ylim Vertical range of plot
 #' @param OutlineLyrs Switch for outlining layers (default = FALSE)
 #' @param emphasizeLayers emphasize layers with different transparency than others, or a different color altogether? then set this argument to `TRUE` if you want to emphasize all
@@ -30,8 +32,9 @@
 #' @param ylab y-axis label; disable ylab by providing an empty string (i.e., ylab = '')
 #' @param xlab x-axis label; disable xlab by providing an empty string (i.e., xlab = '')
 #' @param box Draw a box around the plot (default = TRUE)
-#' @param xticklabels Label the profiles with their "names", "originalIndices" (prior to sorting), "dates", or a custom character array
+#' @param xticklabels Label the profiles with their "names", "originalIndices" (prior to sorting), "dates", "datetimes", or a custom character array
 #' @param xtick.las Orientation of labels if xticklabels is specified.
+#' @param ytick.las Orientation of y-axis labels
 #' @param yPadding Padding between ylim and limits of data, default = 10.
 #' Note that R will still put padding by default. If you want to prohibit that entirely, specify `xaxs ='i'`, or `yaxs = 'i'`.
 #' @param xPadding Padding between xlim and limits of data, default = 0.5.
@@ -42,10 +45,13 @@
 #' @param hardnessScale A scaling factor that exaggerates the hardness profile to subsequent cells on the x-axis. Useful
 #' for time series of sparse profile observations. Note that this scaling factor is unused when `hardnessScale = 1` and that
 #' it gets more influential the smaller `hardnessScale` gets. Also note, that a `hardnessScale > 1` can lead to profiles overlapping.
-#' @param hardnessOffset offsets the profile location on the x-axis
+#' @param xOffset offsets the profile location on the x-axis
+#' @param xScale stretches the horizontal space of each profile. This should ideally be 1, but if you have a 3-hourly profile resolution and
+#' want the plot to display without data gaps, you can set this to 3. Warning: Please note, that this may lead to unnoticed profile overlap if not calibrated properly!
 #' @param k a sorting vector if `SortMethod = "presorted"`.
 #' @param offset Provide a Date or POSIXct offset if you want to offset the vertical snow height/depth axis so that the offset date aligns with snow depth/height 0.
 #' @param add add the plot to an existing plot, or create new plot?
+#' @param tz timezone of your snowprofileSet (for DateStart and DateEnd filtering)
 #' @param ... Additional parameters passed to plot()
 #'
 #' @seealso [plot.snowprofile], [SPgroup]
@@ -55,7 +61,24 @@
 #' @examples
 #'
 #' ## Standard profile timeline (e.g. https://niviz.org)
-#' plot(SPtimeline)
+#' plot(SPtimeline)                              # hourly timeseries
+#' plot(SPtimeline, SortMethod = "time_daily")   # daily timeseries
+#'
+#' ## Change time series date(time) labels:
+#' plot(SPtimeline, Timeseries_labels = "daily", xtick.las = 1)
+#' plot(SPtimeline, Timeseries_labels = "daily 00:00", xtick.las = 1)
+#' plot(SPtimeline,
+#'      xticklabels = c("one", "two", "three", "", "", "",
+#'                      "seven", "", "nine", "", "eleven"),
+#'      Timeseries_labels = NA, xtick.las = 1)
+#'
+#' ## Deal with data gaps originating from discontinuous timeseries
+#' ## hourly timeseries, representing raw data
+#' plot(SPtimeline_3hourly,
+#'      xOffset = 0, Timeseries_labels = "daily")
+#' ## hourly timeseries, stretched to fill missing hours for a continuous plot
+#' plot(SPtimeline_3hourly, xScale = 3,
+#'      xOffset = 0, Timeseries_labels = "daily")
 #'
 #' ## Group of profiles with same timestamp
 #' plot(SPgroup, SortMethod = 'unsorted')  # sorted in same order as list
@@ -71,16 +94,19 @@
 #' ## Timelines with specific date ranges
 #' plot(SPtimeline, DateEnd = '2017-12-17')
 #' plot(SPtimeline, DateStart = '2017-12-15', DateEnd = '2017-12-17')
+#' plot(SPtimeline, DateStart = "2017-12-16 19:00",
+#'      Timeseries_labels = "daily 00:00", xtick.las = 1)
 #'
 #' ## Show hardness profile, too:
-#' plot(SPtimeline, hardnessResidual = 0.5)
+#' plot(SPtimeline, hardnessResidual = 0.1, hardnessScale = 10)
 #'
 #' ## Additional examples of plot dimensions and labelling
 #' ## Label the indices of the profiles in the list:
 #' plot(SPgroup, SortMethod = 'elev', xticklabels = "originalIndices")
 #' ##  ... and with minimized axis limits and their station ID names:
-#' plot(SPgroup, SortMethod = 'elev', xticklabels = sapply(SPgroup, function(x) x$station_id),
-#'        yPadding = 0, xPadding = 0, xaxs = 'i', yaxs = 'i')
+#' plot(SPgroup, SortMethod = 'elev',
+#'      xticklabels = sapply(SPgroup, function(x) x$station_id),
+#'      yPadding = 0, xPadding = 0, xaxs = 'i', yaxs = 'i')
 #' ##  sorted by depth, and without box:
 #' plot(SPgroup, SortMethod = 'hs', TopDown = TRUE, box = FALSE)
 #'
@@ -107,12 +133,12 @@
 #'
 
 plot.snowprofileSet <- function(x,
-                                SortMethod = c("time", "unsorted", "hs", "elev", "presorted"),
-                                ColParam = c("gtype", "hardness", "density", "temp", "gsize", "ssi", "p_unstable", "crit_cut_length", "rta", "percentage"),
+                                SortMethod = c("time", "time_daily", "unsorted", "hs", "elev", "presorted"),
+                                ColParam = c("gtype", "hardness", "density", "temp", "gsize", "ssi", "p_unstable", "crit_cut_length", "rta", "percentage", "lwc"),
                                 TopDown = FALSE,
                                 DateStart = NA,
                                 DateEnd = NA,
-                                Timeseries_labels = c("weekly", "monthly", NA),
+                                Timeseries_labels = c("weekly", "monthly", "daily", "daily HH:MM", NA),
                                 ylim = NULL,
                                 OutlineLyrs = FALSE,
                                 emphasizeLayers = NULL,
@@ -128,14 +154,17 @@ plot.snowprofileSet <- function(x,
                                 box = TRUE,
                                 xticklabels = FALSE,
                                 xtick.las = 2,
+                                ytick.las = 1,
                                 yPadding = 10,
                                 xPadding = 0.5,
                                 hardnessResidual = 1,
                                 hardnessScale = 1,
-                                hardnessOffset = -0.5,
+                                xOffset = -0.5,
+                                xScale = 1,
                                 k = NULL,
                                 offset = as.Date(NA),
                                 add = FALSE,
+                                tz = "UTC",
                                 ...) {
 
 
@@ -147,11 +176,11 @@ plot.snowprofileSet <- function(x,
     stop("plot.snowprofileSet requires an object of class snowprofileSet")
 
   ## SortMethod
-  if (!(SortMethod[1] %in% c("time", "hs", "elev", "unsorted", "presorted")))
-    stop(paste("SortMethod", SortMethod, "not supported ('time', 'hs', 'elev', 'unsorted')"))
+  if (!(SortMethod[1] %in% c("time", "time_daily", "hs", "elev", "unsorted", "presorted")))
+    stop(paste("SortMethod", SortMethod, "not supported ('time', 'time_daily', 'hs', 'elev', 'unsorted')"))
 
   ## ColParam
-  if (!(ColParam[1] %in% c("gtype", "hardness", "density", "temp", "gsize", "ssi", "p_unstable", "crit_cut_length", "rta", "percentage")))
+  if (!(ColParam[1] %in% c("gtype", "hardness", "density", "temp", "gsize", "ssi", "p_unstable", "crit_cut_length", "rta", "percentage", "lwc")))
     stop(paste("ColParam", ColParam, "not supported"))
 
 
@@ -161,9 +190,13 @@ plot.snowprofileSet <- function(x,
   Metadata <- summary(Profiles, fast = FALSE)
 
   ## Filter dates
-  if (SortMethod[1] == "time") {
+  if (grepl("time", SortMethod[1])) {
     ## Filter date range
-    Drop <- c(which(Metadata$date < DateStart), which(Metadata$date > DateEnd))
+    if (SortMethod[1] == "time") {
+      Drop <- c(which(Metadata$datetime < as.POSIXct(DateStart, tz=tz)), which(Metadata$datetime > as.POSIXct(DateEnd, tz=tz)))
+    } else {
+      Drop <- c(which(Metadata$date < DateStart), which(Metadata$date > DateEnd))
+    }
     if (length(Drop) > 0) {
       Profiles <- Profiles[-Drop]
       if (length(Profiles) == 0)
@@ -174,7 +207,9 @@ plot.snowprofileSet <- function(x,
 
   ## Sort profiles
   if (SortMethod[1] == "time") {
-    k <- order(Metadata$date)
+    k <- order(Metadata$datetime)
+  } else if (SortMethod[1] == "time_daily") {
+    k <- order(Metadata$datetime)
   } else if (SortMethod[1] == "hs") {
     k <- order(Metadata$hs)
   } else if (SortMethod[1] == "elev") {
@@ -190,7 +225,6 @@ plot.snowprofileSet <- function(x,
   if (!is.null(OutlineProfile)) OutlineProfile <- sapply(OutlineProfile, function(op) which(k == op))
 
   ## ---- Calculate xy positions of layers ----
-
   ## offset layer locations based on a given offset Date
   if (!is.na(offset)) {
     # tz_used <- NA
@@ -208,7 +242,7 @@ plot.snowprofileSet <- function(x,
     } else if (!inherits(offset, "Date")) stop("offset needs to be of class Date or POSIXct!")
 
     offset_profiles <- lapply(Profiles, function(sp) {
-      sp_d <- deriveDatetag(sp)
+      sp_d <- guessDatetagsSimple.snowprofile(sp, adjust_bdates = TRUE, checkMonotonicity = FALSE)
       idx_offset <- which.min(abs(sp_d$layers$datetag - offset))
       sp_d$layers$height <- sp_d$layers$height - sp_d$layers$height[idx_offset]
       return(sp_d)
@@ -233,16 +267,19 @@ plot.snowprofileSet <- function(x,
 
   ## Rbind all the profiles to get table with all layers
   Lyrs <- rbind(Profiles)
-
   ## X values (index or date) Calculate index for each unique profile
   internal_idx <- unlist(sapply(seq_along(Metadata$nLayers), function(i) rep(i, times = Metadata$nLayers[i])))
   Lyrs$index <- cumsum(!duplicated(Lyrs[c("station_id", "datetime")]))
   if (length(unique(Lyrs$index)) < nrow(Metadata)) Lyrs$index <- as.vector(internal_idx)
   xx <- Lyrs$index
   if (SortMethod[1] == "time") {
+  xx <- Lyrs$datetime
+    if (any(duplicated(Metadata$datetime)))
+      warning("Multiple profiles exist with same datetime. Since SortMethod = 'time' profiles are being plotted on top of each other on these date(s).")
+  } else if (SortMethod[1] == "time_daily") {
     xx <- Lyrs$date
     if (any(duplicated(Metadata$date)))
-      warning("Multiple profiles exist with same date. Since SortMethod = 'time' profiles are being plotted on top of each other on these date(s).")
+      warning("Multiple profiles exist with same date. Since SortMethod = 'time_daily' profiles are being plotted on top of each other on these date(s).")
   }
 
   ## Y-axis values (layer height/depths) Default draw rectangles with tops at 'height' and bottoms at lower interface
@@ -279,6 +316,8 @@ plot.snowprofileSet <- function(x,
     Lyrs$Col <- getColoursStability(Lyrs$rta, StabilityIndexThreshold = 0.8, StabilityIndexRange = c(0, 1))
   } else if (ColParam[1] == "percentage") {
     Lyrs$Col <- getColoursPercentage(Lyrs$percentage, ClrRamp = "Greys_transparent")
+  } else if (ColParam[1] == "lwc") {
+    Lyrs$Col <- getColoursLWC(Lyrs$lwc)
   } else {
     Lyrs$Col <- "#E8E8E8"
   }
@@ -297,10 +336,36 @@ plot.snowprofileSet <- function(x,
   ## ---- Set plot dimensions ----
 
   ## xlim
-  if (length(xPadding) == 2) xlim <- c(0.5 - xPadding[1], length(Profiles) + 0.5 + xPadding[2]) else xlim <- c(0.5 - xPadding, length(Profiles) + 0.5 + xPadding)
-  if (SortMethod[1] == "time") {
-    if (length(xPadding) == 2) xlim <- c(min(xx) - xPadding[1], max(xx + xPadding[2])) else xlim <- c(min(xx) - xPadding, max(xx + xPadding))
-    if (any(is.na(xlim))) stop("Profiles do not contain date information, SortMethod 'time' is not available, try SorthMethod = 'unsorted'")
+  if (length(xPadding) == 2) {
+      xlim <- c(0.5 - xPadding[1], length(Profiles) + 0.5 + xPadding[2])
+    } else {
+      xlim <- c(0.5 - xPadding, length(Profiles) + 0.5 + xPadding)
+    }
+  if (SortMethod[1] %in% c("time", "time_daily")) {
+    if (is.na(DateStart)) {
+      xlim1 <- min(xx)
+    } else {
+      if (SortMethod[1] == "time") {
+        xlim1 <- as.POSIXct(DateStart, tz=tz)
+      } else {
+        xlim1 <- as.Date(DateStart)
+      }
+    }
+    if (is.na(DateEnd)) {
+      xlim2 <- max(xx)
+    } else {
+      if (SortMethod[1] == "time") {
+        xlim2 <- as.POSIXct(DateEnd, tz=tz)
+      } else {
+        xlim2 <- as.Date(DateEnd)
+      }
+    }
+    if (length(xPadding) == 2) {
+      xlim <- c(xlim1 - xPadding[1], xlim2 + xPadding[2])
+    } else {
+      xlim <- c(xlim1 - xPadding, xlim2 + xPadding)
+    }
+    if (any(is.na(xlim))) stop("Profiles do not contain date information, SortMethods 'time' are not available, try SorthMethod = 'unsorted'")
   }
 
   ## ylim
@@ -321,7 +386,6 @@ plot.snowprofileSet <- function(x,
 
 
   ## ---- Draw plot ----
-
   ## Initialize empty plot
   if (!add) {
     plot(NA, NA, type = "n",
@@ -340,18 +404,27 @@ plot.snowprofileSet <- function(x,
   if (length(Hardness) < length(xx)) Hardness <- rep(0, times = length(xx))
 
   ## Draw profiles by creating individual layer rectangles
-  rect(xleft = xx + hardnessOffset,
+  if (SortMethod[1] == "time") {
+    xOffset = xOffset * 60*60  # convert units of days into units of seconds
+    hardnessResidual = hardnessResidual * 60*60
+    hardnessScalingBaseUnit = 3600
+  } else {
+    hardnessScalingBaseUnit = 1
+  }
+  rect(xleft = xx + xOffset,
        ybottom = y1,
-       xright = xx + hardnessOffset + hardnessResidual + Hardness*hardnessScale*(1-hardnessResidual),
+       xright = xx + xOffset + xScale*hardnessResidual + Hardness*hardnessScale*(hardnessScalingBaseUnit-hardnessResidual),
        ytop = y2,
        col = Lyrs$Col,
        border = ifelse(OutlineLyrs == FALSE, NA, "#606060"))
 
+
+
   ## Outline individual profiles by creating individual rectangles
   if (!is.null(OutlineProfile)) {
-    rect(xleft = OutlineProfile + hardnessOffset,
+    rect(xleft = OutlineProfile + xOffset,
          ybottom = sapply(OutlineProfile, function(op) min(y1[xx %in% op])),
-         xright = OutlineProfile + hardnessOffset + hardnessResidual + 1*hardnessScale*(1-hardnessResidual),
+         xright = OutlineProfile + xOffset + xScale*hardnessResidual + 1*hardnessScale*(1-hardnessResidual),
          ytop = sapply(OutlineProfile, function(op) max(y2[xx %in% op])),
          col = NA,
          border = "#606060")
@@ -360,16 +433,16 @@ plot.snowprofileSet <- function(x,
   ## Emphasize specific, individual layers
   if (!all(is.null(emphasizeLayers))) {
     if (emphasizeLayersofinterest) {
-      rect(xleft = xx[Lyrs$layerOfInterest] + hardnessOffset,
+      rect(xleft = xx[Lyrs$layerOfInterest] + xOffset,
            ybottom = y1[Lyrs$layerOfInterest],
-           xright = xx[Lyrs$layerOfInterest] + hardnessOffset + hardnessResidual + Hardness[Lyrs$layerOfInterest]*hardnessScale*(1-hardnessResidual),
+           xright = xx[Lyrs$layerOfInterest] + xOffset + xScale*hardnessResidual + Hardness[Lyrs$layerOfInterest]*hardnessScale*(1-hardnessResidual),
            ytop = y2[Lyrs$layerOfInterest],
            col = Lyrs$emphasisCol[Lyrs$layerOfInterest],
            border = ifelse(OutlineLyrs == FALSE, NA, "#606060"))
     } else if ("toEmphasize" %in% names(Lyrs)) {
-      rect(xleft = xx[Lyrs$toEmphasize] + hardnessOffset,
+      rect(xleft = xx[Lyrs$toEmphasize] + xOffset,
            ybottom = y1[Lyrs$toEmphasize],
-           xright = xx[Lyrs$toEmphasize] + hardnessOffset + hardnessResidual + Hardness[Lyrs$toEmphasize]*hardnessScale*(1-hardnessResidual),
+           xright = xx[Lyrs$toEmphasize] + xOffset + xScale*hardnessResidual + Hardness[Lyrs$toEmphasize]*hardnessScale*(1-hardnessResidual),
            ytop = y2[Lyrs$toEmphasize],
            col = Lyrs$emphasisCol[Lyrs$toEmphasize],
            border = ifelse(OutlineLyrs == FALSE, NA, "#606060"))
@@ -390,24 +463,59 @@ plot.snowprofileSet <- function(x,
   } else if (all(xticklabels == "names")) {
     axis(1, at = 1:length(Profiles), labels = names(x)[k], las = xtick.las)
   } else if (length(xticklabels) > 1) {
-    axis(1, at = 1:length(Profiles), labels = xticklabels[k], las = xtick.las)
+    if (SortMethod[1] == "time"){
+      axis(1, at = summary(Profiles)$datetime, labels = xticklabels[k], las = xtick.las)
+    } else if (SortMethod[1] == "time_daily"){
+      axis(1, at = summary(Profiles)$date, labels = xticklabels[k], las = xtick.las)
+    } else {
+      axis(1, at = 1:length(Profiles), labels = xticklabels[k], las = xtick.las)
+    }
   } else if (all(xticklabels == "dates")) {
-    if (!SortMethod[1] == "time") stop("xticklabels 'date' are currently only implemented for SortMethod 'time'.")
+    if (!SortMethod[1] == c("time", "time_daily")) stop("xticklabels 'dates' are currently only implemented for SortMethods 'time'.")
     axis(1, at = unique(xx), labels = format(unique(xx), "%b %d"), las = xtick.las)
+  } else if (all(xticklabels == "datetimes")) {
+    if (!SortMethod[1] %in% c("time", "time_daily")) stop("xticklabels 'datetimes' are currently only implemented for SortMethods 'time'.")
+    # axis(1, at = unique(xx), labels = format(unique(xx), "%b %d %H:%M"), las = xtick.las)
   }
 
-  if (SortMethod[1] == "time") {
+  if (SortMethod[1] %in% c("time", "time_daily")) {
     if (!is.na(Timeseries_labels[1])) {
-
-      DateArray <- seq(xlim[1], xlim[2], by = "days")
-      Saturdays <- DateArray[weekdays(DateArray, abbreviate = FALSE) == "Saturday"]
-      SaturdayLabels <- format(DateArray[weekdays(DateArray, abbreviate = FALSE) == "Saturday"], "%b %d")
-      if (Timeseries_labels[1] == "monthly") {
-        Saturdays <- Saturdays[seq(1, length(Saturdays), 4)]
-        SaturdayLabels <- SaturdayLabels[seq(1, length(SaturdayLabels), 4)]
+      if (isFALSE(xticklabels) & SortMethod[1] == "time") xticklabels = "datetimes"
+      if (all(xticklabels == "datetimes")) {
+        DateTimeArray <- seq(xlim1, xlim2, by = "hours")
+        SaturdayTimes <- DateTimeArray[
+          weekdays(as.Date(DateTimeArray), abbreviate = FALSE) == "Saturday" &
+            format(DateTimeArray, "%H:%M") == "12:00"
+        ]
+        SaturdayLabels <- format(SaturdayTimes, "%b %d %H:%M")
+        if (Timeseries_labels[1] == "monthly") {
+          print("The combination of xticklabels = datetimes and Timeseries_labels = monthly is not implemented")
+        } else if (grepl("daily", Timeseries_labels[1])) {
+          if (Timeseries_labels[1] == "daily") {
+            time_part <- "12:00"
+          } else {
+            time_part <- regmatches(Timeseries_labels[1], gregexpr("\\d{2}:\\d{2}", Timeseries_labels[1]))[[1]]
+          }
+          SaturdayTimes <- DateTimeArray[
+            format(DateTimeArray, "%H:%M") == time_part
+          ]
+          SaturdayLabels <- format(SaturdayTimes, "%b %d %H:%M")
+        }
+      } else {  # xticklabels = dates
+        DateArray <- seq(xlim1, xlim2, by = "days")
+        SaturdayTimes <- DateArray[weekdays(DateArray, abbreviate = FALSE) == "Saturday"]
+        SaturdayLabels <- format(DateArray[weekdays(DateArray, abbreviate = FALSE) == "Saturday"], "%b %d")
+        if (Timeseries_labels[1] == "monthly") {
+          SaturdayTimes <- SaturdayTimes[seq(1, length(SaturdayTimes), 4)]
+          SaturdayLabels <- SaturdayLabels[seq(1, length(SaturdayLabels), 4)]
+        } else if (grepl("daily", Timeseries_labels[1])) {
+          SaturdayTimes <- DateArray
+          SaturdayLabels <- format(DateArray, "%b %d")
+        }
       }
-      if (VerticalGrid) abline(v = Saturdays, lty = 3, col = "dark grey")
-      axis(1, at = Saturdays, labels = SaturdayLabels, las = xtick.las)
+
+      if (VerticalGrid) abline(v = SaturdayTimes, lty = 3, col = "dark grey")
+      axis(1, at = SaturdayTimes, labels = SaturdayLabels, las = xtick.las)
     }
   }
 
@@ -417,9 +525,9 @@ plot.snowprofileSet <- function(x,
     else yaxisLoc <- 2
     HeightGrid <- pretty(ylim, n = 4)
     if (TopDown) {
-      axis(yaxisLoc, at = HeightGrid, labels = -HeightGrid)
+      axis(yaxisLoc, at = HeightGrid, labels = -HeightGrid, las = ytick.las)
     } else {
-      axis(yaxisLoc, at = HeightGrid, labels = HeightGrid)
+      axis(yaxisLoc, at = HeightGrid, labels = HeightGrid, las = ytick.las)
     }
     if (HorizGrid) abline(h = HeightGrid, lty = 3, col = "dark grey")
   }
@@ -429,4 +537,3 @@ plot.snowprofileSet <- function(x,
   if (box) box()
 
 }
-
