@@ -5,6 +5,7 @@
 #' @import data.table
 #'
 #' @param Filename Path to a smet file
+#' @param HeaderOnly Read only Header information and return as Data.Frame?
 #'
 #' @return List containing metadata and data
 #' @export
@@ -20,7 +21,10 @@
 #' Wx = readSmet(Filename)
 #' str(Wx)
 #'
-readSmet <- function(Filename) {
+#' Header <- readSmet(Filename, HeaderOnly = TRUE)
+#' Header
+#'
+readSmet <- function(Filename, HeaderOnly = FALSE) {
 
   ## ---- Read profile ----
 
@@ -28,18 +32,18 @@ readSmet <- function(Filename) {
   SmetExt <- c(".smet", ".sno")
   if (!any(endsWith(Filename, SmetExt))) stop(paste(Filename, "needs extension:", paste(SmetExt, collapse = " ")))
 
-  ## Initialize list to hold data
-  Wx <- list()
-
   ## Read line (use ~ separator to get single column)
   Lines <- data.table::fread(Filename, sep = "~", data.table = FALSE)
   Lines <- Lines[, 1]
 
   ## ---- Parse contents ----
 
-  ## Determine rows where sections start
-  HeaderIndex <- which(startsWith(Lines, "[HEADER]"))
-  DataIndex <- which(startsWith(Lines, "[DATA]"))
+  ## Initialize empty object
+  Wx <- list()
+
+  ## Determine index of Sections
+  HeaderIndex <- which(Lines == "[HEADER]")
+  DataIndex <- which(Lines == "[DATA]")
 
   ## Read header into a list
   Header <- Lines[(HeaderIndex + 1):(DataIndex - 1)]
@@ -50,16 +54,22 @@ readSmet <- function(Filename) {
     Value <- KeyValue[2]
     if (Key %in% c("fields", "units_offset", "units_multiplier",
                    "plot_unit", "plot_description", "plot_color")) {
-        Value <- unlist(strsplit(Value, " "))
-        Value <- Value[Value != ""]
+      Value <- unlist(strsplit(Value, " "))
+      Value <- Value[Value != ""]
     } else {
-        Value <- gsub(" ", "", Value)
+      Value <- gsub(" ", "", Value)
     }
     Wx[[Key]] <- type.convert(Value, as.is = TRUE)
   }
+  ## Faster, vectorized approach: but need loop anyways for gsub modifications..
+  # Header <- data.table::fread(Filename, sep = "=", skip = HeaderIndex+1, nrows = DataIndex-HeaderIndex-2, data.table = FALSE)
+  # Wx <- as.list(Header[, 2])
+  # names(Wx) <- Header[, 1]
+
+  if (HeaderOnly) return(Wx)
 
   ## Read data
-  Data <- read.csv(textConnection(Lines[(DataIndex + 1):length(Lines)]), sep = "")
+  Data <- read.csv(textConnection(Lines[(DataIndex + 1):length(Lines)]), sep = "", header = F)
   stopifnot(ncol(Data) == length(Wx$fields))
   names(Data) <- Wx$fields
 
