@@ -197,7 +197,7 @@ new_snowprofile <- function(station = character(),
 #'
 #' ## Test profile:
 #' testProfile <- snowprofile(station = 'SARPstation', station_id = 'SARP007',
-#'                            datetime = as.POSIXct('2019/04/01 10:00:00', tz = 'PDT'),
+#'                            datetime = as.POSIXct('2019/04/01 10:00:00', tz = 'Etc/GMT+7'),
 #'                            latlon = c(49.277223, -122.915084), aspect = 180,
 #'                            layers = snowprofileLayers(height = c(10, 25, 50),
 #'                                                       hardness = c(3, 2, 1),
@@ -311,7 +311,7 @@ snowprofile <- function(station = as.character(NA),
 
   ## drop NAs and run checks:
   if (dropNAs) {
-    toKeep <- unique(c(mandatory_fields, names(which(!(sapply(object, function(x) (all(is.na(x)) || isTRUE(all(dim(x)[[1]] == 0))) ))))))
+    toKeep <- unique(c(mandatory_fields, names(which(!sapply(object, function(x) all(is.na(x)) || ((is.data.frame(x) || is.matrix(x)) && nrow(x) == 0) || length(x) == 0)))))
     object <- object[toKeep]
     class(object) <- "snowprofile"
   }
@@ -530,7 +530,7 @@ reformat_snowprofile <- function(profile, currentFields = NULL, targetFields = N
         profile$layers[lconv] <- do.call(paste0("as.", layerTypes[lconv][[1]][[1]]), unname(profile$layers[lconv]))
         if (lconv %in% c("gtype","gtype_sec")){
           unknown_gtypes <- which(!profile$layers[[lconv]] %in% c(grainDict$gtype, NA_character_))
-          if (length(unknown_gtypes > 0)) warning("There are be unknown grain types in your profile...simplifying them to their parent classes!")
+          if (length(unknown_gtypes > 0)) warning("There are unknown grain types in your profile...simplifying them to their parent classes!")
           converted_gtypes <- substr(as.character(profile$layers[[lconv]][unknown_gtypes]), 1, 2)
           profile$layers[lconv] <- as.character(profile$layers[[lconv]])
           profile$layers[[lconv]][unknown_gtypes] <- converted_gtypes
