@@ -162,8 +162,13 @@ snowprofileCaaml <- function(caamlFile,
   ## strip namespace from xml-object if it's from SnowPilot.org
   #  and name node-identifiers accordingly
   sourceSoftware <- "NA"  # deliberately use a string here!
-  if ("snowpilot" %in% names(xml_ns(obj))) sourceSoftware <- "snowpilot"
-  if (isTRUE(sourceSoftware == "snowpilot")) {
+  if ("snowpilot" %in% names(xml_ns(obj))) {
+    sourceSoftware <- "snowpilot"
+  }
+  application <- try(as.character(xml_text(xml_find_all(obj, "caaml:application"))), silent = TRUE)
+  if (length(application) == 0) application <- NA
+
+  if (isTRUE(sourceSoftware == "snowpilot") & is.na(application)) {
     xml_ns_strip(obj)
   ## Explanation: Niviz exports its caaml files with a caaml namespace, so individual nodes are
   # named e.g. 'caaml:timePosition'. On the other hand SnowPilot exports without such a namespace prefix.
@@ -181,13 +186,14 @@ snowprofileCaaml <- function(caamlFile,
   datetimeRAW <- gsub("T", " ", as.character(xml_text(xml_find_all(obj, prefix_slash("timePosition")))))
   datetime <- as.POSIXct(substr(datetimeRAW, 1, 23), tz = "UTC")
 
-
   ## ---Source and comments----
   observer <- paste(xml_text(xml_contents(xml_contents(xml_find_all(obj, prefix_slash("srcRef"))))), collapse = "|")
-  try({com <- xml_text(xml_child(xml_find_first(obj, prefix_plain("metaData")), prefix_plain("comment")))
-       if (!is.na(com)) comment_general <- com}, silent = TRUE)
-  try({com_loc <- xml_text(xml_child(xml_child(xml_find_all(obj, prefix_slash("locRef")), prefix_plain("metaData")), prefix_plain("comment")))
-       if (!is.na(com_loc)) comment_location <- com_loc}, silent = TRUE)
+  com <- NA
+  try(com <- xml_text(xml_child(xml_find_first(obj, prefix_plain("metaData")), prefix_plain("comment"))), silent = TRUE)
+  if (!is.na(com)) comment_general <- com
+  com_loc <- NA
+  try(com_loc <- xml_text(xml_child(xml_child(xml_find_all(obj, prefix_slash("locRef")), prefix_plain("metaData")), prefix_plain("comment"))), silent = TRUE)
+  if (!is.na(com_loc)) comment_location <- com_loc
 
   ## ---Location----
   ## maybe still naming problems with some software?
@@ -209,6 +215,7 @@ snowprofileCaaml <- function(caamlFile,
   if (length(angle) == 0) angle <- as.numeric(NA)
   aspect_node <- xml_child(xml_find_all(locRef, prefix_slash("AspectPosition")), prefix_plain("position"))
   aspect <- tryCatch({xml_double(aspect_node)}, warning = function(w) char2numAspect(xml_text(aspect_node)))
+  if (length(aspect) != 0 && is.na(aspect)) try(aspect <- char2numAspect(xml_text(aspect_node)))
   if (length(aspect) == 0) aspect <- as.numeric(NA)
   lonlat <- strsplit(xml_text(xml_find_all(obj, ".//gml:pos")), split = " ")
   if (length(lonlat) == 0) {
@@ -227,11 +234,12 @@ snowprofileCaaml <- function(caamlFile,
   ## ---profile Depth or SnowHeight, HST----
   hS <- xml_find_all(obj, prefix_slash("hS"))
   ## sometimes, hS can contain a 'components' nodeset with the actual hS stored as a child height:
-  heightTotal <- tryCatch(xml_double(hS),
-                          warning = function(w) {
-                            choices <- c(xml_double(xml_child(hS, prefix_slash("height"))),
-                                         xml_double(xml_child(hS, prefix_slash("snowHeight"))))
-                            choices[!is.na(choices)]})
+  choices <- c(xml_double(xml_child(hS, prefix_slash("height"))),
+               xml_double(xml_child(hS, prefix_slash("snowHeight"))))
+  heightTotal <- choices[!is.na(choices)]
+  if (is.na(heightTotal)){
+    heightTotal <- xml_double(hS)
+  }
 
   pD <- xml_double(xml_find_all(obj, prefix_slash("profileDepth")))
   maxObservedDepth <- as.double(NA)
@@ -240,16 +248,16 @@ snowprofileCaaml <- function(caamlFile,
   }
 
   ## snowpack conditions (i.a. HST):
-  try({spackCondMeta_node <- xml_child(xml_find_first(obj, prefix_slash("snowPackCond")), prefix_plain("metaData"))
-      if (!is.na(spackCondMeta_node)) {
-        comment_spack <- xml_text(xml_child(spackCondMeta_node), prefix_plain("comment"))
-        com_HST_check <- grep("HST[0-9]{1,3}", comment_spack)  # returns index if pattern 'HST###' exists
-        if (length(com_HST_check) != 0) {
-          com_HST <- gsub(".*(HST[0-9]{1,3}).*", "\\1", comment_spack)  # returns 'HST###'
-          HST <- as.numeric(strsplit(com_HST, "HST")[[1]][2])
-        }
-      }
-    }, silent = TRUE)
+  spackCondMeta_node <- try(xml_child(xml_find_first(obj, prefix_slash("snowPackCond")), prefix_plain("metaData")), silent = TRUE)
+  if (!is.na(spackCondMeta_node)) {
+    comment_spack <- NA
+    comment_spack <- xml_text(xml_child(spackCondMeta_node), prefix_plain("comment"))
+    if (!is.na(comment_spack)) com_HST_check <- grep("HST[0-9]{1,3}", comment_spack)  # returns index if pattern 'HST###' exists
+    if (length(com_HST_check) != 0) {
+      com_HST <- gsub(".*(HST[0-9]{1,3}).*", "\\1", comment_spack)  # returns 'HST###'
+      HST <- as.numeric(strsplit(com_HST, "HST")[[1]][2])
+    }
+  }
 
   ## ---Snow layers----
   ## Extract layers, arange in data.frame (subfunction) and write to snowprofile object:
@@ -278,7 +286,7 @@ snowprofileCaaml <- function(caamlFile,
 
   ## stratigraphy metadata, such as Layer of Concern
   loc_node <- character()
-  try({loc_node <- suppressWarnings(xml_find_all(layers_snow, ".//snowpilot:layerOfConcern"))}, silent = TRUE)
+  try(loc_node <- suppressWarnings(xml_find_all(layers_snow, ".//snowpilot:layerOfConcern")), silent = TRUE)
   if (length(loc_node) > 0) {
     loc_idx <- xml_double(loc_node)
     if (measurement_dir == "top down") {
@@ -326,7 +334,7 @@ snowprofileCaaml <- function(caamlFile,
 
   ## Whumpf Study info:
   whumpf_node <- character()
-  whumpf_node <- try({suppressWarnings(xml_find_all(xml_find_first(obj, prefix_plain("metaData")), ".//snowpilot:whumpfData"))}, silent = TRUE)
+  whumpf_node <- try(suppressWarnings(xml_find_all(xml_find_first(obj, prefix_plain("metaData")), ".//snowpilot:whumpfData")), silent = TRUE)
   if (length(whumpf_node) > 0 & !inherits(whumpf_node, "try-error")) {
     whumpfCracking <- ifelse(xml_text(xml_child(whumpf_node, "whumpfCracking")) == "true", TRUE, FALSE)
     whumpfNoCracking <- ifelse(xml_text(xml_child(whumpf_node, "whumpfNoCracking")) == "true", TRUE, FALSE)
