@@ -210,7 +210,10 @@ snowprofileLayers <- function(height = as.double(NA),
 
   } else {
     ## warn if recycling values due to different lengths of input vectors
-    if (any(diff(sapply(entries[!is.na(entries)], length)) != 0)) warning("not all inputs have the same length, recycling..")
+    entry_lengths <- vapply(entries[!is.na(entries)], length, integer(1))
+    if (length(entry_lengths) > 1L && any(diff(entry_lengths) != 0)) {
+      warning("not all inputs have the same length, recycling..")
+    }
     ## create data.frame
     object <- data.frame(entries,
                          stringsAsFactors = TRUE)
@@ -476,4 +479,3 @@ validate_snowprofileLayers <- function(object, silent = FALSE) {
 
 }
 
-
